@@ -2084,6 +2084,7 @@ class TargetApplications:
     name_mapping={
         "calling_regions": "callingRegions",
         "termination_cidrs": "terminationCidrs",
+        "cps": "cps",
     },
 )
 class Termination:
@@ -2092,15 +2093,19 @@ class Termination:
         *,
         calling_regions: typing.Sequence[builtins.str],
         termination_cidrs: typing.Sequence[builtins.str],
+        cps: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''
         :param calling_regions: Calling Regions for VoiceConnector (optional). Default: - ['US']
         :param termination_cidrs: termination IP for VoiceConnector (optional). Default: - none
+        :param cps: CPS Limit. Default: - 1
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "calling_regions": calling_regions,
             "termination_cidrs": termination_cidrs,
         }
+        if cps is not None:
+            self._values["cps"] = cps
 
     @builtins.property
     def calling_regions(self) -> typing.List[builtins.str]:
@@ -2122,6 +2127,15 @@ class Termination:
         assert result is not None, "Required property 'termination_cidrs' is missing"
         return typing.cast(typing.List[builtins.str], result)
 
+    @builtins.property
+    def cps(self) -> typing.Optional[jsii.Number]:
+        '''CPS Limit.
+
+        :default: - 1
+        '''
+        result = self._values.get("cps")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
